Output handling
===============


.. index::
   single: OutputHandler

OrientationImageMapper
----------------------

.. autoclass:: mumott.output_handling.OrientationImageMapper
   :members:
   :undoc-members:

.. index::
   single: ProjectionViewer

ProjectionViewer
----------------

.. autoclass:: mumott.output_handling.ProjectionViewer
   :members:
   :undoc-members:
